pub struct Schedule<'a> { /* private fields */ }
Timer’s schedule

Implementations

Sets initial timeout to fire timer.

Sets timeout interval to run periodically after initial has been fired

Note that if timeout is zero behavior depends on underlying OS API. But most often than note it will fire immediately.

Schedules timer execution, using provided settings.

Returns true if successfully set, otherwise on error returns false